using System;
using System.IO;
using System.Xml.Serialization;

namespace WinForm
{
    public class AmortCalcFormSettings
    {
        public static readonly string SETTINGS_FILE;
        public static readonly string STATE_FILE;

        private int _maxRowHeight = 10;
        private bool _doSave = true;
        private bool _allowSave = false;

        public AmortCalcFormSettings()
        {
            if (!File.Exists(SETTINGS_FILE))
                File.Create(SETTINGS_FILE).Close();
            if (!File.Exists(STATE_FILE))
                File.Create(STATE_FILE).Close();
        }
        static AmortCalcFormSettings()
        {
            string startPath = System.Windows.Forms.Application.StartupPath;

            SETTINGS_FILE = Path.Combine(startPath, "settings.xml");
            STATE_FILE = Path.Combine(startPath, "savedstate.xml");
        }

        /// <summary>Max number of rows to show when auto-expanding</summary>
        public int MaxRowHeight
        {
            get { return _maxRowHeight; }
            set
            {
                _maxRowHeight = value;
                SaveState();
            }
        }

        /// <summary>Whether to save state across sessions</summary>
        public bool DoSave
        {
            get { return _doSave; }
            set
            {
                _doSave = value;
                SaveState();
            }
        }

        /// <summary>Disable this while deserializing, else errors will occur</summary>
        public bool AllowSave
        {
            get { return _allowSave; }
            set { _allowSave = value; }
        }
        public void SaveState()
        {
            if (!AllowSave)
                return;

            XmlSerializer serializer = new XmlSerializer(typeof(AmortCalcFormSettings));
            TextWriter writer = new StreamWriter(SETTINGS_FILE);
            serializer.Serialize(writer, this);
            writer.Close();
        }
    }
}
