using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;
using System.Windows.Forms;

namespace WinForm
{
    [DefaultEvent("Submitted")]
    public partial class EntryTextBox : TextBox
    {
        public EntryTextBox()
        {
            InitializeComponent();
        }

        public EntryTextBox(IContainer container)
        {
            container.Add(this);

            InitializeComponent();
        }

        protected override void OnKeyPress(KeyPressEventArgs e)
        {
            if (e.KeyChar == (char)13)
            {
                e.Handled = true;
                OnSubmitted();
            }
            else
                base.OnKeyPress(e);
        }

        protected override void OnLeave(EventArgs e)
        {
            base.OnLeave(e);
            OnSubmitted();
        }

        protected override void OnEnter(EventArgs e)
        {
            base.OnEnter(e);

            // when textbox gets focus, highlight text with cursor at the end
            this.SelectAll();
        }

        protected virtual void OnSubmitted()
        {
            if (Submitted != null)
                Submitted(this, new EventArgs());
        }

        /// <summary>Submitted is fired when the enter key is pressed or when the textbox loses focus. ie OnLeave</summary>
        [Category("Focus"), Description("Occurs when the textbox loses focus (ie: OnLeave) or when the enter key is pressed")]
        public event EventHandler Submitted;
    }
}
